package org.libreoffice.example.dialog;

import org.libreoffice.example.helper.DialogHelper;

import com.sun.star.awt.ActionEvent;
import com.sun.star.awt.PosSize;
import com.sun.star.awt.Rectangle;
import com.sun.star.awt.Size;
import com.sun.star.awt.XActionListener;
import com.sun.star.awt.XButton;
import com.sun.star.awt.XCheckBox;
import com.sun.star.awt.XComboBox;
import com.sun.star.awt.XDialog;
import com.sun.star.awt.XDialogEventHandler;
import com.sun.star.awt.XFixedHyperlink;
import com.sun.star.awt.XFixedText;
import com.sun.star.awt.XLayoutConstrains;
import com.sun.star.awt.XListBox;
import com.sun.star.awt.XTextComponent;
import com.sun.star.awt.XWindow;
import com.sun.star.lang.EventObject;
import com.sun.star.lang.WrappedTargetException;
import com.sun.star.uno.UnoRuntime;
import com.sun.star.uno.XComponentContext;


public class ActionOneDialog implements XDialogEventHandler {
	
	private XDialog dialog;
	private static final String actionOk = "actionOk";
	private String[] supportedActions = new String[] { actionOk };
	
        public ActionOneDialog(XComponentContext xContext)
        {
          this.dialog = DialogHelper.createDialog("ActionOneDialog.xdl", xContext, this);
          
          XButton button = DialogHelper.getButton(dialog, "Resize");
          button.addActionListener(new XActionListener()
          {

            @Override
            public void disposing(EventObject arg0)
            {
            }

            @Override
            public void actionPerformed(ActionEvent arg0)
            {
              String output = "Control: %s, calculated Width %d, maximum Width %d, calculated Height %d";
              Size max = new Size(500, 50);
              Size size;
              XLayoutConstrains lc;
              XWindow window;
              Rectangle r = null;

              XFixedText label = DialogHelper.getLabel(dialog, "Label1");
              lc = UnoRuntime.queryInterface(XLayoutConstrains.class, label);
              size = lc.calcAdjustedSize(max);
              System.out.println(String.format(output, "Label1", size.Width, max.Width, size.Height));
              window = UnoRuntime.queryInterface(XWindow.class, label);
              r = window.getPosSize();
              window.setPosSize(r.X, r.Y, size.Width, size.Height, PosSize.POSSIZE);

              XTextComponent text = DialogHelper.getEditField(dialog, "TextField1");
              lc = UnoRuntime.queryInterface(XLayoutConstrains.class, text);
              size = lc.calcAdjustedSize(max);
              System.out.println(String.format(output, "TextField1", size.Width, max.Width, size.Height));
              window = UnoRuntime.queryInterface(XWindow.class, text);
              r = window.getPosSize();
              window.setPosSize(r.X, r.Y, size.Width, size.Height, PosSize.POSSIZE);

              XListBox list = DialogHelper.getListBox(dialog, "ListBox1");
              lc = UnoRuntime.queryInterface(XLayoutConstrains.class, list);
              size = lc.calcAdjustedSize(max);
              System.out.println(String.format(output, "ListBox1", size.Width, max.Width, size.Height));
              window = UnoRuntime.queryInterface(XWindow.class, list);
              r = window.getPosSize();
              window.setPosSize(r.X, r.Y, size.Width, size.Height, PosSize.POSSIZE);

              XComboBox combo = DialogHelper.getCombobox(dialog, "ComboBox1");
              lc = UnoRuntime.queryInterface(XLayoutConstrains.class, combo);
              size = lc.calcAdjustedSize(max);
              System.out.println(String.format(output, "ComboBox1", size.Width, max.Width, size.Height));
              window = UnoRuntime.queryInterface(XWindow.class, combo);
              r = window.getPosSize();
              window.setPosSize(r.X, r.Y, size.Width, size.Height, PosSize.POSSIZE);

              XCheckBox check = DialogHelper.getCheckBox(dialog, "CheckBox1");
              lc = UnoRuntime.queryInterface(XLayoutConstrains.class, check);
              size = lc.calcAdjustedSize(max);
              System.out.println(String.format(output, "CheckBox1", size.Width, max.Width, size.Height));
              window = UnoRuntime.queryInterface(XWindow.class, check);
              r = window.getPosSize();
              window.setPosSize(r.X, r.Y, size.Width, size.Height, PosSize.POSSIZE);

              XFixedHyperlink link = DialogHelper.getLink(dialog, "Hyper1");
              lc = UnoRuntime.queryInterface(XLayoutConstrains.class, link);
              size = lc.calcAdjustedSize(max);
              System.out.println(String.format(output, "Hyper1", size.Width, max.Width, size.Height));
              window = UnoRuntime.queryInterface(XWindow.class, link);
              r = window.getPosSize();
              window.setPosSize(r.X, r.Y, size.Width, size.Height, PosSize.POSSIZE);
            }
          });
          
	}

	public void show() {
		dialog.execute();
	}
	
	private void onOkButtonPressed() {
		dialog.endExecute();
	}
	
	@Override
	public boolean callHandlerMethod(XDialog dialog, Object eventObject, String methodName) throws WrappedTargetException {
		if (methodName.equals(actionOk)) {
			onOkButtonPressed();
			return true; // Event was handled
		}
		return false; // Event was not handled
	}

	@Override
	public String[] getSupportedMethodNames() {
		return supportedActions;
	}

}
